@@ -1,6 +1,7 @@
 import click
 
-from cli.utils import Spotify
+from ..utils import Spotify
+from ..utils.exceptions import NoPlaybackError
 
 
 @click.command(options_metavar='[<options>]')
@@ -24,7 +25,8 @@ def repeat(mode, verbose=0, quiet=False, _create_request=False):
     }
     request = {
         'endpoint': 'me/player/repeat?state={}'.format(state_map[mode]),
-        'method': 'PUT'
+        'method': 'PUT',
+        'handle_errs': {404: NoPlaybackError},
     }
     if _create_request:
         return request
@@ -42,6 +44,9 @@ def repeat(mode, verbose=0, quiet=False, _create_request=False):
             click.echo('Repeat set to all tracks.')
     else:
         from cli.commands.status import status
-        status.callback(verbose=verbose, _override={'is_repeat': mode in ['all', 'track']})
+        status.callback(
+            verbose=verbose,
+            _override={'is_repeat': mode in ['all', 'track']}
+        )
 
     return
