@@ -13,6 +13,11 @@ from cli.commands.volume import volume
 from cli.commands.shuffle import shuffle
 from cli.commands.repeat import repeat
 from cli.commands.save import save
+from cli.commands.queue import queue
+from cli.commands.browse import browse
+from cli.commands.history import history
+from cli.commands.top import top
+from cli.commands.search import search
 
 
 # CLI group
@@ -25,6 +30,7 @@ from cli.commands.save import save
 def cli():
     pass
 
+
 # commands
 cli.add_command(auth)
 cli.add_command(status)
@@ -37,3 +43,8 @@ cli.add_command(volume)
 cli.add_command(shuffle)
 cli.add_command(repeat)
 cli.add_command(save)
+cli.add_command(queue)
+cli.add_command(browse)
+cli.add_command(history)
+cli.add_command(top)
+cli.add_command(search)
